<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sv">
<context>
    <name>Batchprocessing</name>
    <message>
        <location filename="../src/batchprocessing.cpp" line="54"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="55"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>Nuvarande kärna stöder inte vald kompressionsalgoritm, var vänlig redigera konfigurationsfilen och välj en annan algoritm.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="80"/>
        <source>The program will pause the build and open the boot menu in your text editor.</source>
        <translation>Programmet kommer att pausa byggandet och öppna boot-menyn i din textredigerare.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="162"/>
        <source>No diff output available.</source>
        <translation>Ingen utdata från diff tillgänglig.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="200"/>
        <source>Default exclusion file not found at %1.</source>
        <translation>Standard exklusionsfil inte hittad på %1.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="212"/>
        <source>Could not backup existing exclusion file to %1.</source>
        <translation>Kunde inte backa upp befintlig exklusionsfil till %1.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="215"/>
        <source>Could not remove existing exclusion file at %1.</source>
        <translation>Kunde inte ta bort existerande exklusionsfil på %1.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="222"/>
        <source>Could not copy default exclusion file from %1 to %2.</source>
        <translation>Kunde inte kopiera standard exklusionsfil från %1 till %2.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="238"/>
        <source>Detected newer exclusion file at %1 compared to %2. Prompting for action.</source>
        <translation>Upptäckte nyare exklusionsfil på %1 jämfört med %2. Uppmanar till handling.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="244"/>
        <source>s</source>
        <comment>CLI excludes prompt: single-letter shortcut for 'show diff'</comment>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="245"/>
        <source>u</source>
        <comment>CLI excludes prompt: single-letter shortcut for 'use updated default'</comment>
        <translation>u</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="246"/>
        <source>k</source>
        <comment>CLI excludes prompt: single-letter shortcut for 'keep custom (update timestamp)'</comment>
        <translation>k</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="247"/>
        <source>q</source>
        <comment>CLI excludes prompt: single-letter shortcut for 'quit'</comment>
        <translation>q</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="249"/>
        <source>show diff</source>
        <comment>CLI excludes prompt option label</comment>
        <translation>visa diff</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="250"/>
        <source>use updated default</source>
        <comment>CLI excludes prompt option label</comment>
        <translation>använd uppdaterad standard</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="251"/>
        <source>keep custom (update timestamp)</source>
        <comment>CLI excludes prompt option label</comment>
        <translation>behåll anpassad (uppdatera tidsstämpel)</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="252"/>
        <source>quit</source>
        <comment>CLI excludes prompt option label</comment>
        <translation>avsluta</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="255"/>
        <source>[%1]%2  [%3]%4  [%5]%6  [%7]%8: </source>
        <translation>[%1]%2  [%3]%4  [%5]%6  [%7]%8: </translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="260"/>
        <source>The exclusion file at %1 is newer than your configured file at %2.</source>
        <translation>Exklusionsfilen på %1 är nyare än din konfigurerade fil på %2.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="276"/>
        <source>Reverted to updated default exclusion file.</source>
        <translation>Återgick till uppdaterad standard exklusionsfil.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="297"/>
        <source>Leaving custom exclusion file unchanged.</source>
        <translation>Låter anpassad exklusionsfil vara oförändrad.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="308"/>
        <source>Invalid choice. Please select again.</source>
        <translation>Ogiltigt val. Var vänlig välj igen.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="315"/>
        <source>This computer uses an NVIDIA graphics card. Are you planning to use the resulting ISO on the same computer or another computer with an NVIDIA card?</source>
        <translation>Den här datorn använder ett NVIDIA grafikkort. Tänker du använda resulterande ISO på samma datorr eller en annan dator med ett NVIDIA-kort?</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="325"/>
        <source>Note: If you use the resulting ISO on a computer without an NVIDIA card, you will likely need to remove &apos;xorg=nvidia&apos; from the boot options.</source>
        <translation>Anmärkning: om du använder resulterande ISO på en dator utan ett NVIDIA kort, behöver du troligen ta bort &apos;xorg=nvidia&apos; från boot-alternativen.</translation>
    </message>
    <message>
        <location filename="../src/batchprocessing.cpp" line="328"/>
        <source>Note: If you use the resulting ISO on a computer with an NVIDIA card, you may need to add &apos;xorg=nvidia&apos; to the boot options.</source>
        <translation>Anmärkning: om du använder resulterande ISO på en dator med ett NVIDIA kort, behöver du troligen lägga till &apos;xorg=nvidia&apos; till boot-alternativen.</translation>
    </message>
</context>
<context>
    <name>Cmd</name>
    <message>
        <location filename="../src/cmd.cpp" line="82"/>
        <source>No elevation tool found (pkexec/gksu/sudo).</source>
        <translation>Inget elevationsverktyg hittat (pkexec/gksu/sudo).</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="116"/>
        <source>Administrator Access Required</source>
        <translation>Administratörbehörighet krävs</translation>
    </message>
    <message>
        <location filename="../src/cmd.cpp" line="117"/>
        <source>This operation requires administrator privileges. Please restart the application and enter your password when prompted.</source>
        <translation>Denna operation kräver administratörprivilegier. Var vänlig starta om programmet  och skriv in ditt lösenord när det krävs.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <location filename="../src/mainwindow.cpp" line="446"/>
        <location filename="../src/mainwindow.cpp" line="832"/>
        <location filename="../src/ui_mainwindow.h" line="745"/>
        <source>MX Snapshot</source>
        <translation>MX Snapshot</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="33"/>
        <location filename="../src/ui_mainwindow.h" line="746"/>
        <source>Optional customization</source>
        <translation>Valfri anpassning</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="65"/>
        <location filename="../src/ui_mainwindow.h" line="747"/>
        <source>Release version:</source>
        <translation>Utgåvans version:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="79"/>
        <location filename="../src/ui_mainwindow.h" line="748"/>
        <source>Boot options:</source>
        <translation>Boot-alternativ:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="86"/>
        <location filename="../src/ui_mainwindow.h" line="749"/>
        <source>Live kernel:</source>
        <translation>Live-kärna:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="93"/>
        <location filename="../src/ui_mainwindow.h" line="750"/>
        <source>Project name:</source>
        <translation>Projektnamn:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="100"/>
        <location filename="../src/ui_mainwindow.h" line="751"/>
        <source>Release date:</source>
        <translation>Utgivningsdatum:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="107"/>
        <location filename="../src/ui_mainwindow.h" line="752"/>
        <source>Release codename:</source>
        <translation>Utgåvans kodnamn:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="133"/>
        <location filename="../src/ui_mainwindow.h" line="753"/>
        <source>Current date</source>
        <translation>Nuvarande datum</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="172"/>
        <location filename="../src/ui_mainwindow.h" line="754"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot är ett verktyg som skapar en bootbar avbild (ISO) av ditt nuvarande system som du kan använda för lagring eller distribuering. Du kan fortsätta att arbeta med lätta program medan det körs.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="182"/>
        <location filename="../src/ui_mainwindow.h" line="755"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>Använt utrymme på / (root) och /home partitioner:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="192"/>
        <location filename="../src/ui_mainwindow.h" line="756"/>
        <source>Location and ISO name</source>
        <translation>Område och ISO-namn:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="219"/>
        <location filename="../src/ui_mainwindow.h" line="758"/>
        <source>Snapshot location:</source>
        <translation>Snapshotets plats</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="226"/>
        <location filename="../src/ui_mainwindow.h" line="759"/>
        <source>Select a different snapshot directory</source>
        <translation>Välj en annan snapshot katalog</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="236"/>
        <location filename="../src/mainwindow.cpp" line="641"/>
        <location filename="../src/ui_mainwindow.h" line="760"/>
        <source>Snapshot name:</source>
        <translation>Snapshotets namn</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="360"/>
        <location filename="../src/ui_mainwindow.h" line="764"/>
        <source>Type of snapshot:</source>
        <translation>Typ av snapshot:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="367"/>
        <location filename="../src/ui_mainwindow.h" line="765"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>Bevara konton (för personlig backup)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="377"/>
        <location filename="../src/ui_mainwindow.h" line="767"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Detta alternativ kommer att återställa &amp;quot;demo&amp;quot; och &amp;quot;root&amp;quot; lösenorden till MX Linux standardvärde och kommer inte att kopiera några personliga konton som skapats.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="380"/>
        <location filename="../src/ui_mainwindow.h" line="769"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Återställa konton (för distribution till andra)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="451"/>
        <location filename="../src/ui_mainwindow.h" line="770"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation>Du kan också undanta speciella kataloger genom att kryssa för de vanliga valen nedan, eller genom att klicka på knappen för att direkt redigera  /etc/mx-snapshot-exclude.list.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="496"/>
        <location filename="../src/ui_mainwindow.h" line="771"/>
        <source>sha512</source>
        <translation>sha512</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="519"/>
        <location filename="../src/ui_mainwindow.h" line="773"/>
        <source>Throttle the I/O input rate by the given percentage.</source>
        <translation>Stryp I/O inmatningshastighet med given procentsats.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="525"/>
        <location filename="../src/ui_mainwindow.h" line="775"/>
        <source>I/O throttle:</source>
        <translation>I/O strypning:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="532"/>
        <location filename="../src/ui_mainwindow.h" line="776"/>
        <source>Calculate checksums:</source>
        <translation>Beräkna kontrollsummor:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="539"/>
        <location filename="../src/ui_mainwindow.h" line="777"/>
        <source>ISO compression scheme:</source>
        <translation>ISO kompressions-schema:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="546"/>
        <location filename="../src/ui_mainwindow.h" line="778"/>
        <source>Number of CPU cores to use:</source>
        <translation>Antal CPU-kärnor att använda:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="553"/>
        <location filename="../src/ui_mainwindow.h" line="779"/>
        <source>md5</source>
        <translation>md5</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="563"/>
        <location filename="../src/ui_mainwindow.h" line="780"/>
        <source>Options:</source>
        <translation>Alternativ:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="610"/>
        <location filename="../src/ui_mainwindow.h" line="781"/>
        <source>Edit Exclusion File</source>
        <translation>Redigera Exklusionsfil</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="626"/>
        <location filename="../src/mainwindow.cpp" line="852"/>
        <location filename="../src/ui_mainwindow.h" line="782"/>
        <source>Remove Custom Exclusion File</source>
        <translation>Ta bort anpassad Exklusionsfil</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="679"/>
        <location filename="../src/ui_mainwindow.h" line="783"/>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="686"/>
        <location filename="../src/ui_mainwindow.h" line="784"/>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="693"/>
        <location filename="../src/ui_mainwindow.h" line="785"/>
        <source>All of the above</source>
        <translation>Alla ovan nämnda</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="700"/>
        <location filename="../src/ui_mainwindow.h" line="787"/>
        <source>exclude network configurations</source>
        <translation>undanta nätverkskonfigurationer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="703"/>
        <location filename="../src/ui_mainwindow.h" line="789"/>
        <source>Networks</source>
        <translation>Nätverk</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="710"/>
        <location filename="../src/ui_mainwindow.h" line="790"/>
        <source>Downloads</source>
        <translation>Nerladdningar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="717"/>
        <location filename="../src/ui_mainwindow.h" line="791"/>
        <source>Desktop</source>
        <translation>Skrivbord</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="724"/>
        <location filename="../src/ui_mainwindow.h" line="792"/>
        <source>Documents</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="731"/>
        <location filename="../src/ui_mainwindow.h" line="793"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="738"/>
        <location filename="../src/ui_mainwindow.h" line="794"/>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="850"/>
        <location filename="../src/ui_mainwindow.h" line="797"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="853"/>
        <location filename="../src/ui_mainwindow.h" line="799"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="859"/>
        <location filename="../src/ui_mainwindow.h" line="801"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="875"/>
        <location filename="../src/ui_mainwindow.h" line="803"/>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="900"/>
        <location filename="../src/ui_mainwindow.h" line="808"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="903"/>
        <location filename="../src/ui_mainwindow.h" line="810"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="909"/>
        <location filename="../src/ui_mainwindow.h" line="812"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="922"/>
        <location filename="../src/ui_mainwindow.h" line="815"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="925"/>
        <location filename="../src/ui_mainwindow.h" line="817"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="931"/>
        <location filename="../src/ui_mainwindow.h" line="819"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="985"/>
        <location filename="../src/ui_mainwindow.h" line="822"/>
        <source>Back</source>
        <translation>Bakåt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="408"/>
        <source>Select Release Date</source>
        <translation>Välj utgivningsdatum</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="452"/>
        <source>fastest, worst compression</source>
        <translation>snabbaste, sämsta kompression</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="452"/>
        <source>fast, worse compression</source>
        <translation>snabb, sämre kompression</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="453"/>
        <source>slow, better compression</source>
        <translation>långsam, bättre kompression</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="453"/>
        <source>best compromise</source>
        <translation>bästa kompromiss</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="454"/>
        <source>slowest, best compression</source>
        <translation>långsammast, bästa kompression</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="483"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Fritt utrymme på %1, där snapshotkatalogen är placerad:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="486"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space by removing previous snapshots and saved copies: %1 snapshots are taking up %2 of disk space.</source>
        <translation>Det fria utrymmet ska vara tillräckligt för att innehålla den komprimerade datan från / och /home

      Om det är nödvändigt, kan du skapa mer tillgängligt utrymme genom att ta bort tidigare snapshots och sparade kopior: %1 snapshots upptar %2 av diskutrymmet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="498"/>
        <location filename="../src/mainwindow.cpp" line="499"/>
        <source>Installing </source>
        <translation>Installerar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="584"/>
        <source>Please wait.</source>
        <translation>Var vänlig vänta.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="586"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>Var vänlig vänta. Beräknar använt hårddiskutrymme...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="313"/>
        <location filename="../src/mainwindow.cpp" line="330"/>
        <location filename="../src/mainwindow.cpp" line="337"/>
        <location filename="../src/mainwindow.cpp" line="620"/>
        <location filename="../src/mainwindow.cpp" line="627"/>
        <location filename="../src/mainwindow.cpp" line="708"/>
        <location filename="../src/mainwindow.cpp" line="727"/>
        <location filename="../src/mainwindow.cpp" line="966"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="177"/>
        <source>No diff output available.</source>
        <translation>Ingen utdata från diff tillgänglig.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="210"/>
        <location filename="../src/mainwindow.cpp" line="246"/>
        <source>Updated Exclusion List</source>
        <translation>Uppdaterad Exklusionslista</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="213"/>
        <source>The exclusion file at %1 is newer than your configured file at %2.</source>
        <translation>Exklusionsfilen på %1 är nyare än din konfigurerade fil på %2.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="215"/>
        <source>Review the changes below. Keep your custom file or replace it with the updated default.</source>
        <translation>Kontrollera ändringarna nedan. Behåll din anpassade fil eller ersätt den med uppdaterad standard</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="221"/>
        <source>Show Differences</source>
        <translation>Visa Skillnader</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="227"/>
        <source>Keep Custom</source>
        <translation>Behåll Anpassad</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="233"/>
        <source>Use Updated Default</source>
        <translation>Använd Uppdaterad Standard</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="314"/>
        <source>Default exclusion file not found at %1.</source>
        <translation>Standard exklusionsfil inte hittad på %1.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="326"/>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="327"/>
        <source>Could not backup existing exclusion file to %1.</source>
        <translation>Kunde inte backa upp befintlig exklusionsfil till %1.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="331"/>
        <source>Could not remove existing exclusion file at %1.</source>
        <translation>Kunde inte ta bort existerande exklusionsfil på %1.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="338"/>
        <source>Could not copy default exclusion file from %1 to %2.</source>
        <translation>Kunde inte kopiera standard exklusionsfil från %1 till %2.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="621"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation>Output fil %1 finns redan. Var vänlig använd annat filnamn, eller ta bort den existerande filen.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="628"/>
        <source>Insufficient free space. Please select a different snapshot directory or free up space.</source>
        <translation>Otillräckligt med ledigt utrymme. Var vänlig välj en annan snapshot katalog eller frigör utrymme.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="632"/>
        <source>Settings</source>
        <translation>Inställningar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="638"/>
        <source>Snapshot will use the following settings:</source>
        <translation>Snapshot kommer att använda följande inställningar:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="640"/>
        <source>- Snapshot directory:</source>
        <translation>-Snapshot katalog:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="641"/>
        <source>- Kernel to be used:</source>
        <translation>-Linuxkärna som ska användas:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="664"/>
        <location filename="../src/mainwindow.cpp" line="673"/>
        <source>NVIDIA Detected</source>
        <translation>NVIDIA Upptäckt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="665"/>
        <source>This computer uses an NVIDIA graphics card. Are you planning to use the resulting ISO on the same computer or another computer with an NVIDIA card?</source>
        <translation>Den här datorn använder ett NVIDIA grafikkort. Tänker du använda resulterande ISO på samma datorr eller en annan dator med ett NVIDIA-kort?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="669"/>
        <source>NVIDIA Selected</source>
        <translation>NVIDIA Vald</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="670"/>
        <source>Note: If you use the resulting ISO on a computer without an NVIDIA card, you will likely need to remove &apos;xorg=nvidia&apos; from the boot options.</source>
        <translation>Anmärkning: om du använder resulterande ISO på en dator utan ett NVIDIA kort, behöver du troligen ta bort &apos;xorg=nvidia&apos; från boot-alternativen.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="674"/>
        <source>Note: If you use the resulting ISO on a computer with an NVIDIA card, you may need to add &apos;xorg=nvidia&apos; to the boot options.</source>
        <translation>Anmärkning: om du använder resulterande ISO på en dator med ett NVIDIA kort, behöver du troligen lägga till &apos;xorg=nvidia&apos; till boot-alternativen.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="709"/>
        <source>Could not replace the exclusion file with the updated default.</source>
        <translation>Kunde inte ersätta exklusionsfilen med uppdaterad standard.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="728"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation>Nuvarande kärna stöder inte vald kompressionsalgoritm, var vänlig redigera konfigurationsfilen och välj en annan algoritm.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="751"/>
        <source>Final chance</source>
        <translation>Sista chansen</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="753"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation>Snapshot har nu all information det behöver för att skapa en ISO av systemet du kör.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="754"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation>Det kommer att ta en del tid att avsluta, beroende på storleken av det installerade systemet och din dators prestanda.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="756"/>
        <source>OK to start?</source>
        <translation>OK att börja?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="760"/>
        <source>Shutdown computer when done.</source>
        <translation>Stäng av datorn när det är klart.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="793"/>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="809"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="816"/>
        <source>Edit Boot Menu</source>
        <translation>Redigera Boot Meny</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="817"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation>Programmet kommer nu ta en paus för att låta dig redigera filer i arbetskatalogen. Välj Ja för att redigera boot menyn eller välj Nej för att hoppa över detta steg och fortsätta skapandet av snapshotet.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="853"/>
        <source>Revert the exclusion list to the default file? This will overwrite your current exclusions.</source>
        <translation>Få exklusionsfilen att återgå till standardfilen? Detta kommer att skriva över dina nuvarande exklusioner.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="933"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="935"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="936"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation>Program för att skapa en live-CD från systemet som körs för MX-Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="938"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="940"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="954"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="959"/>
        <source>Select Snapshot Directory</source>
        <translation>Välj Snapshot Katalog</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="967"/>
        <source>Insufficient free space in the selected directory. Please choose a different location.</source>
        <translation>Otillräckligt med ledigt utrymme i den valda katalogen. Var vänlig välj en annan plats.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="987"/>
        <source>Confirmation</source>
        <translation>Bekräftelse</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="987"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>Är du säker på att du vill avsluta programmet?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="94"/>
        <source>Tool used for creating a live-CD from the running system</source>
        <translation>Verktyg för att skapa en live-CD av systemet du kör</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="98"/>
        <source>Use CLI only</source>
        <translation>Använd enbart CLI</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="102"/>
        <source>Number of CPU cores to be used.</source>
        <translation>Antal CPU-kärnor som ska användas.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="103"/>
        <source>Output directory</source>
        <translation>Output-katalog</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="104"/>
        <source>Output filename</source>
        <translation>Output filnamn</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="106"/>
        <source>Name a different kernel to use other than the default running kernel, use format returned by &apos;uname -r&apos;</source>
        <translation>Nämn en annan kärna att använda istället för den kärna som körs som standard, använd formatet som du får av &apos;uname -r&apos;</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="108"/>
        <source>Or the full path: %1</source>
        <translation>Eller hela sökvägen: %1</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="111"/>
        <source>Compression level options.</source>
        <translation>Kompressionsnivå-alternativ.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>Use quotes: &quot;-Xcompression-level &lt;level&gt;&quot;, or &quot;-Xalgorithm &lt;algorithm&gt;&quot;, or &quot;-Xhc&quot;, see mksquashfs man page</source>
        <translation>Använd citationstecken: &quot;-Xcompression-level &lt;level&gt;&quot;, eller &quot;-Xalgorithm &lt;algorithm&gt;&quot;, eller &quot;-Xhc&quot;, se mksquashfs man page</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="116"/>
        <source>Create a monthly snapshot, add &apos;Month&apos; name in the ISO name, skip used space calculation</source>
        <translation>Skapa ett månatligt snapshot, lägg till &apos;Månad&apos;  i ISO namnet, slopa beräkningen av använt utrymme</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="117"/>
        <source>This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored</source>
        <translation>Denna möjlighet ställer in återställnings-konton och kompression till standard, argument som ändrar dessa saker kommer att ignoreras</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="119"/>
        <source>Optionally specify a suffix to add to the month name (e.g., &apos;1&apos; for &apos;July.1&apos;)</source>
        <translation>Valfritt specifiera ett suffix att lägga till månadens namn (dvs &apos;1&apos; för &apos;Juli.1&apos;)</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="120"/>
        <source>Don&apos;t calculate checksums for resulting ISO file</source>
        <translation>Beräkna inte checksums för den slutliga ISO-filen</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="121"/>
        <source>Skip calculating free space to see if the resulting ISO will fit</source>
        <translation>Slopa uträkning av fritt utrymme för att se om den resulterande ISO-filen ryms.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="122"/>
        <source>Option to fix issue with calculating checksums on preempt_rt kernels</source>
        <translation>Alternativ för att fixa problem med beräkning av checksums för preempt_rt kärnor</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="123"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>Återställa konton (för distribution till andra)</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="124"/>
        <source>Calculate checksums for resulting ISO file</source>
        <translation>Beräkna checksums för den slutliga ISO-filen</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="126"/>
        <source>Throttle the I/O input rate by the given percentage. This can be used to reduce the I/O and CPU consumption of Mksquashfs.</source>
        <translation>Stryp I/O inmatningshastighet med angiven procentsats. Detta kan användas för att reducera Mksquashfs I/O och CPU -konsumtion.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="129"/>
        <source>Work directory</source>
        <translation>Arbetskatalog</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="131"/>
        <source>Exclude main folders, valid choices: </source>
        <translation>Exkludera huvudkataloger, giltiga val:</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="133"/>
        <source>Use the option one time for each item you want to exclude</source>
        <translation>Använd möjligheten en gång för varje post du vill exkludera</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="136"/>
        <source>Compression format, valid choices: </source>
        <translation>Kompressionsformat, giltiga val:</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="138"/>
        <source>Shutdown computer when done.</source>
        <translation>Stäng av datorn när det är klart.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="211"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du verkar vara inloggad som root, var vänlig logga ut och logga in som vanlig användare för att använda detta program.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="229"/>
        <source>version:</source>
        <translation>version:</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="223"/>
        <source>You must run this program with sudo or pkexec.</source>
        <translation>Du måste köra detta program med sudo eller pkexec.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="206"/>
        <source>MX Snapshot</source>
        <translation>MX Snapshot</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="213"/>
        <location filename="../src/main.cpp" line="281"/>
        <location filename="../src/settings.cpp" line="527"/>
        <location filename="../src/settings.cpp" line="535"/>
        <location filename="../src/settings.cpp" line="1065"/>
        <location filename="../src/settings.cpp" line="1159"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="280"/>
        <location filename="../src/settings.cpp" line="534"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation>Nuvarande kärna stöder inte Squashfs, kan inte fortsätta.</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="113"/>
        <source>Failed to initialize configuration</source>
        <translation>Misslyckades med att initiera konfigurationen</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="147"/>
        <source>Configuration validation failed</source>
        <translation>Konfigurationsvalidering misslyckades</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="152"/>
        <source>Exception during initialization: %1</source>
        <translation>Undantag under initiering: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="155"/>
        <source>Unknown exception during initialization</source>
        <translation>Okänt undantag under initiering</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="186"/>
        <source>Could not create work directory. </source>
        <translation>Kunde inte skapa arbetskatalog</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="210"/>
        <source>Could not create temp directory:</source>
        <translation>Kunde inte skapa temp katalog:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="211"/>
        <source>Please check that the parent directory exists and is writable:</source>
        <translation>Var vänlig kontrollera att överordnad katalog finns och är skrivbar:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="229"/>
        <source>Compression format &apos;%1&apos; is not supported by the current kernel</source>
        <translation>Kompressionsformat &apos;%1&apos; stöds inte av nuvarande kärna</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="235"/>
        <source>Invalid cores setting: %1. Must be between 1 and %2</source>
        <translation>Ogiltig kärninställning: %1. Måste vara mellan 1 och %2</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="241"/>
        <source>Invalid throttle setting: %1. Must be between 0 and 20</source>
        <translation>Ogiltig strypinställning: %1. Måste vara mellan 0 och 20</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="247"/>
        <source>Snapshot directory cannot be empty</source>
        <translation>Snapshotkatalogen kan inte vara tom</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="255"/>
        <source>Snapshot name cannot be empty</source>
        <translation>Snapshotnamnet kan inte vara tomt</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="261"/>
        <source>Snapshot name contains invalid characters: %1</source>
        <translation>Snapshotnamnet innehåller ogiltiga tecken: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="267"/>
        <source>Kernel version cannot be empty</source>
        <translation>Kärnversion kan inte vara tom</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="272"/>
        <source>Kernel file not found: /boot/vmlinuz-%1</source>
        <translation>Kärnfil ej hittad: /boot/vmlinuz-%1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="278"/>
        <source>Kernel %1 doesn&apos;t support Squashfs</source>
        <translation>Kärna %1 stöder inte Squashfs</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="309"/>
        <source>Exclusion file does not exist: %1</source>
        <translation>Exklusionsfil finns inte: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="318"/>
        <source>Unbalanced quotes in exclusion list</source>
        <translation>Obalanserade citationstecken i exklusionslista</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="343"/>
        <source>Insufficient free space: %1 KiB available, minimum %2 KiB required</source>
        <translation>Otillräckligt fritt utrymme: %1 KiB tillgängligt, minimum %2 KiB behövs</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="350"/>
        <source>Insufficient free space in work directory: %1 KiB available, minimum %2 KiB required</source>
        <translation>Otillräckligt fritt utrymme i arbetskatalog: %1 KiB tillgängligt, minimum %2 KiB behövs</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="365"/>
        <source>Failed to determine number of CPU cores</source>
        <translation>Kunde inte avgöra antal processorkärnor</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="371"/>
        <source>Configuration file does not exist: %1</source>
        <translation>Konfigurationsfil existerar inte: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="372"/>
        <source>Using default settings</source>
        <translation>Med standardinställningar</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="374"/>
        <source>Cannot read configuration file: %1</source>
        <translation>Kan inte läsa konfigurationsfil: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="375"/>
        <source>Error: %1</source>
        <translation>Fel: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="385"/>
        <source>Required tool not found: %1</source>
        <translation>Nödvändigt verktyg ej hittat: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="394"/>
        <source>Required directory not found: %1</source>
        <translation>Nödvändig katalog ej hittad: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="413"/>
        <source>Initialization Error</source>
        <translation>Initieringsfel</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="414"/>
        <source>Failed to initialize application settings:

%1</source>
        <translation>Misslyckades med start av applikationsinställningar:

%1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="525"/>
        <source>Could not find a usable kernel</source>
        <translation>Kunde inte hitta en användbar kärna</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="526"/>
        <source>Searched for kernel files in /boot/ but none were found or accessible.</source>
        <translation>Sökte efter kärnfiler i /boot/ men inga hittades eller var tillgängliga.</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="547"/>
        <source>No users found in the system</source>
        <translation>Inga användare hittade i systemet</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="550"/>
        <source>Failed to determine system information</source>
        <translation>Misslyckades med att avläsa systeminformation</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="644"/>
        <source>Used space on / (root): </source>
        <translation>Använt utrymme på / (root): </translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="647"/>
        <source>estimated</source>
        <translation>uppskattad</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="656"/>
        <source>Used space on /home: </source>
        <translation>Använt utrymme på/home: </translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="712"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>Fritt utrymme på %1, där snapshotkatalogen är placerad:</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="716"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation>Det fria utrymmet borde vara tillräckligt för att rymma den komprimerade datan från / och /home

Om nödvändigt kan du skapa mer tillgängligt utrymme
genom att avlägsna tidigare snapshots och sparade kopior:
%1 snapshots upptar %2 av diskutrymmet
</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="730"/>
        <source>Desktop</source>
        <translation>Skrivbord</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="731"/>
        <source>Documents</source>
        <translation>Dokument</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="732"/>
        <source>Downloads</source>
        <translation>Nerladdningar</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="733"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="734"/>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="735"/>
        <source>Networks</source>
        <translation>Nätverk</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="736"/>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="738"/>
        <source>Videos</source>
        <translation>Video</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="887"/>
        <source>Error reading system configuration file: %1</source>
        <translation>Fel vid läsning av systemkonfigurationsfil: %1</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="895"/>
        <source>Error accessing user configuration</source>
        <translation>Fel vid tillgång till användarkonfiguration</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="947"/>
        <source>Could not copy exclusion file from %1 to %2</source>
        <translation>Kunde inte kopiera exklusionsfil från %1 till %2.</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="972"/>
        <source>Invalid stored cores setting (%1). Using detected CPU count: %2</source>
        <translation>Ogiltig lagrad kärninställning (%1). Använder upptäckt CPU antal: %2</translation>
    </message>
    <message>
        <location filename="../src/settings.cpp" line="1063"/>
        <location filename="../src/settings.cpp" line="1157"/>
        <source>Output file %1 already exists. Please use another file name, or delete the existent file.</source>
        <translation>Output fil %1 finns redan. Var vänlig använd annat filnamn, eller ta bort den existerande filen.</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="70"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="71"/>
        <location filename="../src/about.cpp" line="81"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="72"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="94"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
</context>
<context>
    <name>Work</name>
    <message>
        <location filename="../src/work.cpp" line="147"/>
        <source>Cleaning...</source>
        <translation>Rensar...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="163"/>
        <location filename="../src/work.cpp" line="420"/>
        <source>Done</source>
        <translation>Klar</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="175"/>
        <source>Interrupted or failed to complete</source>
        <translation>Avbruten eller kunde inte fullbordas</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="211"/>
        <location filename="../src/work.cpp" line="376"/>
        <location filename="../src/work.cpp" line="400"/>
        <location filename="../src/work.cpp" line="438"/>
        <location filename="../src/work.cpp" line="578"/>
        <location filename="../src/work.cpp" line="612"/>
        <location filename="../src/work.cpp" line="621"/>
        <location filename="../src/work.cpp" line="627"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="212"/>
        <source>There&apos;s not enough free space on your target disk, you need at least %1</source>
        <translation>Det finns inte tillräckligt mycket utrymme på din måldisk, du behöver åtminstone %1</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="215"/>
        <source>You have %1 free space on %2</source>
        <translation>Du har %1 fritt utrymme på %2</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="218"/>
        <source>If you are sure you have enough free space rerun the program with -o/--override-size option</source>
        <translation>Om du är säker på att du har tillräckligt med fritt utrymme, kör programmet en gång till med  -o/--override-size alternativet</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="304"/>
        <source>Copying the new-iso filesystem...</source>
        <translation>Kopierar new-iso filsystem...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="316"/>
        <source>Could not create temp directory. </source>
        <translation>Kunde inte skapa temp-katalog.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="373"/>
        <source>Squashing filesystem...</source>
        <translation>Squashing filsystem...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="377"/>
        <source>Could not create linuxfs file, please check /var/log/%1.log</source>
        <translation>Kunde inte skapa linuxfs fil, var vänlig kontrollera /var/log/%1.log</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="397"/>
        <source>Creating CD/DVD image file...</source>
        <translation>Skapar CD/DVD avbildsfil...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="401"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation>Kunde inte skapa ISO fil, var vänlig kontrollera om du har tillräckligt med utrymme på målpartitionen.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="407"/>
        <source>Making hybrid iso</source>
        <translation>Skapar hybrid iso</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="425"/>
        <source>Success</source>
        <translation>Det lyckades</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="426"/>
        <source>MX Snapshot completed successfully!</source>
        <translation>MX Snapshot cframgångsrikt avslutat!</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="427"/>
        <source>Snapshot took %1 to finish.</source>
        <translation>Snapshot tog %1 för att avslutas.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="428"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation>Tack för att du använder MX Snapshot, kör sedan MX Live USB Maker! </translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="435"/>
        <source>Installing </source>
        <translation>Installerar</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="438"/>
        <source>Could not install </source>
        <translation>Kunde inte installera</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="448"/>
        <source>Calculating checksum...</source>
        <translation>Beräknar checksum...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="488"/>
        <source>Building new initrd...</source>
        <translation>Skapar ny initrd...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="579"/>
        <source>Could not create working directory. </source>
        <translation>Kunde inte skapa arbetskatalog.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="613"/>
        <source>Could not prepare a safe bind-root overlay. Snapshot cannot continue.</source>
        <translation>Kunde inte förbereda en säker bind-root overlay. Snapshot kan inte fortsätta.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="622"/>
        <location filename="../src/work.cpp" line="628"/>
        <source>Could not prepare the snapshot bind-root environment.</source>
        <translation>Kunde inte förbereda snapshotets bind-root miljö.</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="931"/>
        <source>Calculating total size of excluded files...</source>
        <translation>Beräknar totalstorleken på exkluderade filer...</translation>
    </message>
    <message>
        <location filename="../src/work.cpp" line="957"/>
        <source>Calculating size of root...</source>
        <translation>Beräknar storleken på root...</translation>
    </message>
</context>
</TS>